scripts/install-debugclients.py

branch
maintenance
changeset 8043
0acf98cd089a
parent 7924
8a96736d465e
parent 7960
e8fc383322f7
child 8273
698ae46f40a4
--- a/scripts/install-debugclients.py	Sun Jan 17 13:53:08 2021 +0100
+++ b/scripts/install-debugclients.py	Mon Feb 01 10:38:16 2021 +0100
@@ -3,12 +3,12 @@
 
 # Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for the eric6 debug client. It may be used
 # to just install the debug clients for remote debugging.
 #
 
 """
-Installation script for the eric6 debug clients.
+Installation script for the eric debug clients.
 """
 
 import io
@@ -69,7 +69,7 @@
         print("    {0} [-chz][-d dir] [-i dir]".format(progName))
     print("where:")
     print("    -h, --help display this help message")
-    print("    -d dir     where eric6 debug client files will be installed")
+    print("    -d dir     where eric debug client files will be installed")
     print("               (default: {0})".format(modDir))
     if not sys.platform.startswith("win"):
         print("    -i dir     temporary install prefix")
@@ -105,7 +105,7 @@
     @param dst name of the destination directory
     @param filters list of filter pattern determining the files to be copied
     @param excludeDirs list of (sub)directories to exclude from copying
-    @keyparam excludePatterns list of filter pattern determining the files to
+    @param excludePatterns list of filter pattern determining the files to
         be skipped
     """
     if excludeDirs is None:
@@ -186,7 +186,7 @@
     
     @param src source file name (string)
     @param dst destination file name or directory name (string)
-    @keyparam perm permissions to be set (integer)
+    @param perm permissions to be set (integer)
     """
     shutil.copy(src, dst)
     if os.path.isdir(dst):
@@ -210,7 +210,7 @@
     
     try:
         # Install the files
         # copy the various parts of eric6 debug clients
         copyTree(
             os.path.join(eric6SourceDir, "DebugClients"), targetDir,
             ['*.py', '*.pyc', '*.pyo', '*.pyw'],
@@ -240,8 +240,8 @@
     global progName, modDir, doCleanup, doCompile, distDir
     global sourceDir
     
-    if sys.version_info < (3, 5, 0) or sys.version_info >= (4, 0, 0):
-        print('Sorry, the eric6 debugger requires Python 3.5 or better'
+    if sys.version_info < (3, 6, 0) or sys.version_info >= (4, 0, 0):
+        print('Sorry, the eric debugger requires Python 3.6 or better'
               ' for running.')
         exit(5)
     
@@ -318,7 +318,7 @@
                 rx=skipRe,
                 quiet=True)
         sys.stdout = sys.__stdout__
-    print("\nInstalling eric6 debug clients ...")
+    print("\nInstalling eric debug clients ...")
     res = installEricDebugClients()
     
     print("\nInstallation complete.")
@@ -3,12 +3,12 @@
 # Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is the install script for the eric6 debug client. It may be used
+# This is the install script for the eric debug client. It may be used
 # to just install the debug clients for remote debugging.
 #
@@ -210,7 +210,7 @@
     try:
         # Install the files
-        # copy the various parts of eric6 debug clients
+        # copy the various parts of eric debug clients
         copyTree(
             os.path.join(eric6SourceDir, "DebugClients"), targetDir,

eric ide

mercurial